#ifndef SHARE_H_
#define SHARE_H_

#include  <msp430f2370.h>


/* Functions prototypes */
void system_init(void);
void uart_init(void);
void timer_init(void);
void uart_send(unsigned short);
void M1_move(unsigned short dir);

/* Bit operations */
#define BIT_SET(lval, mask)     ((lval) |= (mask))
#define BIT_CLR(lval, mask)     ((lval) &= ~(mask))
#define BIT_TOOGLE(lval, mask)  ((lval) ^= (mask))
#define BIT_TEST(val, mask)     (((val) & (mask))==(mask))

/* Varibles */
unsigned short work=0, M1_dir=0, M2_dir=0, M3_dir=0, M1_cnt=0, M2_cnt=0, M3_cnt=0;
unsigned long M1_speed=1, M2_speed=1, M3_speed=1, M1_timer=0, M2_timer=0, M3_timer=0;
unsigned short received_message=0;
unsigned long a=0;

// PINS
#define	M1_A		BIT0	//P1.0
#define	M1_B		BIT1	//P1.1
#define	M1_C		BIT2	//P1.2
#define	M1_D		BIT3	//P1.3
#define	M2_A		BIT4	//P1.4
#define	M2_B		BIT5	//P1.5
#define	M2_C		BIT6	//P1.6
#define	M2_D		BIT7	//P1.7
#define	M3_A		BIT0	//P2.0
#define	M3_B		BIT1	//P2.1
#define	M3_C		BIT2	//P2.2
#define	M3_D		BIT3	//P2.3
#define	LED1		BIT4	//P2.4
#define	LED2		BIT5	//P2.5
#define	LED3		BIT6	//P2.6
#define	LED4		BIT7	//P2.7
#define	TXD			BIT4	//P3.4	UART MSP_TXD
#define	RXD			BIT5	//P3.5	UART MSP_RXD



void system_init(void){
	WDTCTL = WDTPW + WDTHOLD;                 	// Stop WDT
	BCSCTL1 = CALBC1_1MHZ;  					// setup DCO
	DCOCTL = CALDCO_1MHZ;

	BIT_SET(P1DIR, M1_A + M1_B + M1_C + M1_D + M2_A + M2_B + M2_C + M2_D);
	BIT_CLR(P1OUT, M1_A + M1_B + M1_C + M1_D + M2_A + M2_B + M2_C + M2_D);

	BIT_SET(P2DIR, LED1 + LED2 + LED3 + LED4);
	BIT_CLR(P2OUT, LED1 + LED2 + LED3 + LED4);

}



void uart_init(void){
	UCA0CTL1 = UCSWRST;							// reset uart
	UCA0CTL1 |= UCSSEL_2;                     	// SMCLK
	UCA0CTL0 = 0;                     			// UART, 1 stop-bit, 8 data-bits, parity none
	UCA0BR0 = 0x68;                             // 1MHz 9600
	UCA0BR1 = 0;                              	// 1MHz 9600
	UCA0MCTL = 0x04;              			 	// Modulation
	BIT_SET(P3SEL, RXD + TXD);                	// P3.4,5 = USCI_A0 TXD/RXD
	UCA0CTL1 &= ~UCSWRST;                     	// **Initialize USCI state machine**
	IE2 |= UCA0RXIE;                          	// Enable USCI_A0 RX interrupt

}

void uart_send(unsigned short data_tx)
{
    while (!(IFG2&UCA0TXIFG)); //    .
    UCA0TXBUF = data_tx;
}


void timer_init(void)
{
	//  
	//  - SMCLK,
	// - 8,
	//  -  ,
	// 
	TACTL |=  TASSEL1 | MC0 | TAIE | ID1 | ID0;

	TACCR0 = 0x7D; //  1
}

void M1_move(unsigned short dir)
{
	M1_cnt++;
	if (dir==0)
	{
		switch (M1_cnt)
		{
			case 1: BIT_SET(P1OUT, M1_A); BIT_CLR(P1OUT, M1_B + M1_C + M1_D); break;
			case 2: BIT_SET(P1OUT, M1_B); BIT_CLR(P1OUT, M1_A + M1_C + M1_D); break;
			case 3: BIT_SET(P1OUT, M1_C); BIT_CLR(P1OUT, M1_A + M1_B + M1_D); break;
			case 4: BIT_SET(P1OUT, M1_D); BIT_CLR(P1OUT, M1_A + M1_B + M1_C); M1_cnt=0; break;
		}

	}
	else
	{
		switch (M1_cnt)
		{
			case 1: BIT_SET(P1OUT, M1_D); BIT_CLR(P1OUT, M1_A + M1_B + M1_C); break;
			case 2: BIT_SET(P1OUT, M1_C); BIT_CLR(P1OUT, M1_A + M1_B + M1_D); break;
			case 3: BIT_SET(P1OUT, M1_B); BIT_CLR(P1OUT, M1_A + M1_C + M1_D); break;
			case 4: BIT_SET(P1OUT, M1_A); BIT_CLR(P1OUT, M1_B + M1_C + M1_D); M1_cnt=0; break;
		}
	}


}


#endif /* SHARE_H_ */
